@@ -74,6 +74,7 @@ def upload(
     working_dir: Path | None = None,
     out_dir: Path = Path(),
     processes: int = 0,
+    connections: int = 4,
     dry_run: bool = False,
     debug: bool = False,
     environment: ENVIRONMENTS = DEFAULT_ENVIRONMENT,
@@ -91,6 +92,7 @@ def upload(
             working_dir=working_dir if working_dir else Path(tmp_dir),
             out_dir=out_dir,
             processes=processes,
+            connections=connections,
             environment=environment,
             json_messages=json_messages,
             save_reads=save_reads,
@@ -106,6 +108,7 @@ def upload_wrapper(
     working_dir: Path | None = None,
     out_dir: Path = Path(),
     processes: int = 0,
+    connections: int = 4,
     dry_run: bool = False,
     debug: bool = False,
     environment: ENVIRONMENTS = DEFAULT_ENVIRONMENT,
@@ -122,6 +125,7 @@ def upload_wrapper(
     :arg working_dir: Path of directory in which to make intermediate files
     :arg out_dir: Path of directory in which to save mapping CSV
     :arg processes: Number of tasks to execute in parallel. 0 = auto
+    :arg connections: Number of uploads performed in parallel
     :arg dry_run: Exit before submitting files
     :arg debug: Emit verbose debug messages
     :arg environment: GPAS environment to use
@@ -135,6 +139,7 @@ def upload_wrapper(
         working_dir=working_dir,
         out_dir=out_dir,
         processes=processes,
+        connections=connections,
         dry_run=dry_run,
         debug=debug,
         environment=environment,
